The "H1N1" dataset provides provincial statistical incidences of influenza A virus subtype H1N1 in China for 2013. It includes H1N1 incidences and related variables across three different spatial grid sizes: 50 km, 100 km, and 150 km. Detailed references and data sources will be added.
h1n1_50h1n1_100
h1n1_150
h1n1_50A data frame with 3977 rows and 11 variables (50 km grid size).
h1n1_100A data frame with 987 rows and 11 variables (100 km grid size).
h1n1_150A data frame with 443 rows and 11 variables (150 km grid size).